Normalization adapters for Git patches and porcelain status output.
Structs
- GitStatus
Entry - One entry from
git status --porcelain=v1 -z. - Untracked
File - Contents for an untracked file, supplied by a native Git host.
Functions
- parse_
git_ diff - Parses and normalizes a multi-file Git diff.
- parse_
porcelain_ v1_ z - Parses
git status --porcelain=v1 -zoutput.