parse_git_diff

Function parse_git_diff 

pub fn parse_git_diff(bytes: &[u8]) -> Result<Vec<FileDiff>, DiffError>
Parses and normalizes a multi-file Git diff.

Errors

Returns an error when the patch is malformed, contains unsupported path encoding, or contains an invalid repository-relative path.